@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = '0.7';
+our $VERSION = '0.8';
 
 BEGIN {
 
@@ -110,12 +110,15 @@ sub set_suffix {
 
 sub _str {
     my $obj = shift;
-    # Flatten array refs...
-    return join '', @$obj
-      if 'ARRAY' eq ref $obj;
-    # ...stringify objects...
-    my $str = eval { $obj->as_string };
-    return $str unless $@;
+    if ( my $ref = ref $obj ) {
+        # Flatten array refs...
+        return join '', @$obj
+          if 'ARRAY' eq $ref;
+        # ...stringify objects...
+        my $str = eval { $obj->as_string };
+        return $str unless $@;
+    }
+
     # ...default stringification
     return "$obj";
 }
@@ -280,7 +283,7 @@ HTML::Tiny - Lightweight, dependency free HTML/XML generation
 
 =head1 VERSION
 
-This document describes HTML::Tiny version 0.7
+This document describes HTML::Tiny version 0.8
 
 =head1 SYNOPSIS
 
